@@ -2,7 +2,7 @@ package Dist::Zilla::Plugin::Test::CPAN::Changes;
 use strict;
 use warnings;
 # ABSTRACT: release tests for your changelog
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use Moose;
 use Data::Section -setup;
@@ -72,7 +72,9 @@ Dist::Zilla::Plugin::Test::CPAN::Changes - release tests for your changelog
 
 =head1 VERSION
 
-version 0.009
+version 0.010
+
+=for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
 
 =head1 SYNOPSIS
 
@@ -99,9 +101,6 @@ if you want to use a different filename for whatever reason, do:
 
 and that file will be tested instead.
 
-=for test_synopsis 1;
-__END__
-
 =for Pod::Coverage gather_files register_prereqs
 
 =head1 AVAILABILITY
@@ -142,8 +141,8 @@ __[ xt/release/cpan-changes.t ]__
 use strict;
 use warnings;
 
-use Test::More 0.96 tests => 2;
-use_ok('Test::CPAN::Changes');
+use Test::More 0.96 tests => 1;
+use Test::CPAN::Changes;
 subtest 'changes_ok' => sub {
     changes_file_ok('CHANGESFILENAME');
 };
